EsimInstallerFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • EsimInstallerFlutterPlatform
Implementers

Constructors

EsimInstallerFlutterPlatform()
Constructs a EsimInstallerFlutterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
installESimProfile({required String smdpAddress, required String activationToken}) → Future<String>
instructions() → Future<String>
isSupportESim() → Future<bool?>
launchIntent({required String smdpAddress, required String activationToken}) → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ EsimInstallerFlutterPlatform
The default instance of EsimInstallerFlutterPlatform to use.
getter/setter pair